@@ -10,8 +10,10 @@ All these are ready to use by using :data:`~jsonext.dumps`.
 import functools
 import json
 
-from .mixins import JSONDateTimeMixin, JSONIterableMixin, JSONToDictMixin, \
-    JSONStringifyMixin
+from .mixins import (
+    JSONDateTimeMixin, JSONIterableMixin, JSONToDictMixin, JSONStringifyMixin,
+)
+from .wrappers import ISO88601Wrapper
 
 
 class JSONEncoder(JSONDateTimeMixin, JSONIterableMixin, JSONToDictMixin,
@@ -19,4 +21,7 @@ class JSONEncoder(JSONDateTimeMixin, JSONIterableMixin, JSONToDictMixin,
     pass
 
 
+JSONDecoder = ISO88601Wrapper(json.JSONDecoder())
+
 dumps = functools.partial(json.dumps, cls=JSONEncoder)
+loads = JSONDecoder.decode
